/* File: SchedulePaneController.java
 *
 * Contains class SchedulePaneController
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.controller;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Observable;

import javax.swing.SwingUtilities;

import edu.cmu.hcii.calo.manager.ScheduleManager;
import edu.cmu.hcii.calo.messagePassing.Message;
import edu.cmu.hcii.calo.messagePassing.MessageTarget;
import edu.cmu.hcii.calo.messagePassing.ScheduleMessage;
import edu.cmu.hcii.calo.view.schedule.SchedulePaneView;

/**
 * The controller that attaches the schedule manager to its corresponding views.
 * 
 * @author Brian Ellis
 */
public class SchedulePaneController extends MessageTarget implements PropertyChangeListener {

	/** The view to control */
	private SchedulePaneView view;

	/** Tells the controller to ignore model messages to assure atomic updates. */
	private boolean ignoreModelMessages;

	/**
	 * Constructs a SchedulePaneController that sends updates to (and listens for property changes
	 * from) the given SchedulePaneView.
	 * 
	 * @param view the view to send updates to
	 */
	public SchedulePaneController(SchedulePaneView view) {
		this.view = view;
		this.ignoreModelMessages = false;
		view.addPropertyChangeListener(this);

		ScheduleManager.getManager().addObserver(this);
		// WizardOfOzEngine.getEngine().addObserver(this);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.cmu.hcii.calo.messagePassing.MessageTarget#onMessageReceived(java.util.Observable,
	 *      edu.cmu.hcii.calo.messagePassing.Message)
	 */
	@Override
	public void onMessageReceived(Observable sender, Message msg) {
		assert (msg instanceof ScheduleMessage) : "schedule pane controller got a message of an unhandleable type";

		// Ensure atomic animation updates
		if (this.ignoreModelMessages) {
			return;
		}

		if (SwingUtilities.isEventDispatchThread()) {
			this.view.update();
			this.view.repaint();
		} else {
			SwingUtilities.invokeLater(new Runnable() {

				@SuppressWarnings("synthetic-access")
				public void run() {
					SchedulePaneController.this.view.update();
					SchedulePaneController.this.view.repaint();
				}

			});
		}
	}

	/**
	 * This method gets called when a bound property is changed.
	 * 
	 * @param e A PropertyChangeEvent object describing the event source and the property that has
	 *            changed.
	 * 
	 * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
	 */
	public void propertyChange(PropertyChangeEvent e) {
	// There are currently no property changes defined for the schedule pane view.
	}
}
