/* File: SidebarController.java
 *
 * Contains class SidebarController
 *
 * Author: Will Haines
 */

package edu.cmu.hcii.calo.controller;

import java.util.Observable;

import javax.swing.SwingUtilities;

import edu.cmu.hcii.calo.WinAppBar;
import edu.cmu.hcii.calo.manager.NotificationManager;
import edu.cmu.hcii.calo.messagePassing.Message;
import edu.cmu.hcii.calo.messagePassing.MessageTarget;
import edu.cmu.hcii.calo.messagePassing.NotificationMessage;
import edu.cmu.hcii.calo.messagePassing.NotificationMessage.NotificationMessageType;

/**
 * The controller that listens for changes to the notification center and revalidates the layout of
 * the sidebar to ensure that the notification center is always the correct size.
 * 
 * @author Will Haines
 */
public class SidebarController extends MessageTarget {

	/**
	 * The sidebar.
	 */
	private WinAppBar sidebar;

	/**
	 * Constructs a SidebarController that validates the given sidebar.
	 * @param sidebar the sidebar
	 */
	public SidebarController(WinAppBar sidebar) {
		this.sidebar = sidebar;

		NotificationManager.getManager().addObserver(this);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.cmu.hcii.calo.messagePassing.MessageTarget#onMessageReceived(java.util.Observable,
	 *      edu.cmu.hcii.calo.messagePassing.Message)
	 */
	@Override
	public void onMessageReceived(Observable sender, Message msg) {
		assert (msg instanceof NotificationMessage || msg instanceof NotificationMessage);
		assert msg.getSender() == NotificationManager.getManager();

		if (msg.getMessageType() == NotificationMessageType.NOTIFICATION_ADDED) {
			// Intentionally left blank
		}

		if (SwingUtilities.isEventDispatchThread()) {
			this.sidebar.validate();
		} else {
			SwingUtilities.invokeLater(new Runnable() {

				@SuppressWarnings("synthetic-access")
				public void run() {
					SidebarController.this.sidebar.validate();
				}

			});
		}
	}
}
