/* File: TaskViewerController.java
 *
 * Contains class TaskViewerController
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.controller;

import java.util.Observable;

import javax.swing.SwingUtilities;

import edu.cmu.hcii.calo.manager.TaskManager;
import edu.cmu.hcii.calo.messagePassing.Message;
import edu.cmu.hcii.calo.messagePassing.MessageTarget;
import edu.cmu.hcii.calo.messagePassing.TaskMessage;
import edu.cmu.hcii.calo.messagePassing.TasklikeObjectMessage;
import edu.cmu.hcii.calo.view.task.viewer.TaskViewerTaskList;

/**
 * The controller that attaches the task manager to the task viewer window. Unlike other
 * controllers, this one does not implement PropertyChangeListener because the task viewer is only a
 * mockup and doesn't post interesting property change events.
 * 
 * @author Brian Ellis
 * 
 */
public class TaskViewerController extends MessageTarget {

	/**
	 * The task list within the task viewer window, which is actually what we need to update.
	 */
	private TaskViewerTaskList list;

	/**
	 * Constructs a TaskViewerController that updates the given task list.
	 * 
	 * @param list the task list to update
	 */
	public TaskViewerController(TaskViewerTaskList list) {
		super();
		this.list = list;
		TaskManager.getManager().addObserver(this);
	}

	/**
	 * @see edu.cmu.hcii.calo.messagePassing.MessageTarget#onMessageReceived(java.util.Observable,
	 *      edu.cmu.hcii.calo.messagePassing.Message)
	 */
	@Override
	public void onMessageReceived(Observable sender, final Message msg) {
		assert (msg instanceof TaskMessage || msg instanceof TasklikeObjectMessage);
		assert msg.getSender() == TaskManager.getManager();

		if (SwingUtilities.isEventDispatchThread()) {
			performUpdate(msg);
		} else {
			SwingUtilities.invokeLater(new Runnable() {

				@SuppressWarnings("synthetic-access")
				public void run() {
					performUpdate(msg);
				}

			});
		}
	}

	/**
	 * Updates the list from the TaskManager.
	 * 
	 * @param msg the message received from the manager
	 */
	private void performUpdate(Message msg) {
		this.list.update();
	}

}
