/*
 * XMLScriptParser.java
 * Contains class XMLScriptParser.
 * Author: Will Haines
 */
package edu.cmu.hcii.calo.engine;

import java.io.FileReader;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.Calendar;
import java.util.GregorianCalendar;

import javax.swing.JOptionPane;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;

import com.sun.org.apache.xerces.internal.parsers.SAXParser;

import edu.cmu.hcii.calo.model.Person;
import edu.cmu.hcii.calo.model.Notification.NotificationType;

/**
 * Parses XML to build the script from which the automated engine takes its
 * directions.
 * 
 * @author Will Haines
 */
public class XMLScriptParser extends DefaultHandler {

	AutomatedEngine engine;

	public XMLScriptParser() {
		super();
		this.engine = AutomatedEngine.getEngine();

		final String inputFile = JOptionPane.showInputDialog(
				"Please enter the XML automation file to use.", "test.xml");
		if (inputFile == null) {
			// User canceled, don't run the parser
			return;
		}

		XMLReader xr = new SAXParser();
		xr.setContentHandler(this);
		xr.setErrorHandler(this);

		try {
			FileReader r = new FileReader(inputFile);
			xr.parse(new InputSource(r));
		} catch (Exception e) {
			System.err.println(e);
		}
	}

	/**
	 * Adds a notification with the given attributes.
	 * 
	 * @param atts
	 *            the vector of attributes of this notification
	 */
	private void addNotification(Attributes atts) {
		String id = atts.getValue("id");
		if (id == null) {
			System.err.println("Failed to parse: notification id");
			id = "DefaultID";
		}
		String nt = atts.getValue("type");
		NotificationType type = NotificationType.EMAIL;
		if (nt == null) {
			System.err.println("Failed to parse: notification " + id + "'s type");
		} else {
			if (nt.equals("email")) {
				type = NotificationType.EMAIL;
			} else if (nt.equals("CALOAction")) {
				type = NotificationType.CALO_ACTION;
			} else if (nt.equals("reminder")) {
				type = NotificationType.REMINDER;
			} else {
				System.err
						.println("Failed to parse: notification " + id + "'s type unknown: "
								+ nt);
			}
		}
		String noteName = atts.getValue("name");
		if (noteName == null) {
			System.err.println("Failed to parse: notification " + id + "'s name");
			noteName = "Unknown";
		}
		String text = atts.getValue("text");
		if (text == null) {
			System.err.println("Failed to parse: notification  " + id + "'s text");
			text = "Unknown";
		}
		String pName = atts.getValue("person");
		Person person = new Person();
		if (pName == null) {
			System.err.println("Failed to parse: notification  " + id + "'s person");
		} else {
			person = new Person(pName);
		}
		double priority = 0.0;
		try {
			priority = Double.valueOf(atts.getValue("priority"));
		} catch (NumberFormatException e) {
			System.err
					.println("Failed to parse: notification " + id + "'s priority invalid");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no priority for notification " + id);
		}

		long time = this.extractTime(atts);
		this.engine.addNotification(id, type, noteName, text, person, priority,
				time);
	}

	/**
	 * Adds a task with the given attributes.
	 * 
	 * @param atts
	 *            the vector of attributes of this task
	 */
	private void addTask(Attributes atts) {
		String id = atts.getValue("id");
		if (id == null) {
			System.err.println("Failed to parse: task id");
			id = "DefaultID";
		}
		String taskName = atts.getValue("name");
		if (taskName == null) {
			System.err.println("Failed to parse: task " + id + "'s name");
			taskName = "Unknown";
		}
		String oh = atts.getValue("onHold");
		boolean onHold = false;
		if (oh == null) {
			System.err.println("Failed to parse: task " + id + "'s on hold");
		} else {
			onHold = (oh.equals("true"));
		}
		String c = atts.getValue("complete");
		boolean complete = false;
		if (c == null) {
			System.err.println("Failed to parse: task " + id + "'s complete");
		} else {
			complete = (c.equals("true"));
		}
		Calendar dueDate = null;
		try {
			dueDate = new GregorianCalendar();
			dueDate.setTime(DateFormat.getDateTimeInstance(DateFormat.MEDIUM,
					DateFormat.MEDIUM).parse(atts.getValue("dueDate")));
		} catch (ParseException e) {
			System.err
			.println("Failed to parse: task " + id + "'s due date invalid");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no due date for task " + id);
		}
		double priority = 0.0;
		try {
			priority = Double.valueOf(atts.getValue("priority"));
		} catch (NumberFormatException e) {
			System.err
			.println("Failed to parse: task " + id + "'s priority invalid");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no priority for task " + id);
		}
		long time = this.extractTime(atts);
		this.engine.addTask(id, taskName, onHold, complete, dueDate, priority,
				time);
	}

	/**
	 * Changes a notification with the given attributes.
	 * 
	 * @param atts
	 *            the vector of attributes of this notification
	 */
	private void changeNotification(Attributes atts) {
		String id = atts.getValue("id");
		if (id == null) {
			System.err.println("Failed to parse: notification id");
			id = "DefaultID";
		}
		String noteName = atts.getValue("name");
		if (noteName == null) {
			System.err.println("Failed to parse: notification " + id + "'s name");
			noteName = "Unknown";
		}
		String text = atts.getValue("text");
		if (text == null) {
			System.err.println("Failed to parse: notification " + id + "'s text");
			text = "Unknown";
		}
		String pName = atts.getValue("person");
		Person person = new Person();
		if (pName == null) {
			System.err.println("Failed to parse: notification " + id + "'s person");
		} else {
			person = new Person(pName);
		}		
		double priority = 0.0;
		try {
			priority = Double.valueOf(atts.getValue("priority"));
		} catch (NumberFormatException e) {
			System.err
					.println("Failed to parse: notification " + id + "'s priority invalid");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no priority for notification " + id);
		}

		long time = this.extractTime(atts);
		this.engine.changeNotification(id, noteName, text, person, priority,
				time);
	}

	/**
	 * Changes a task with the given attributes.
	 * 
	 * @param atts
	 *            the vector of attributes of this task
	 */
	private void changeTask(Attributes atts) {
		String id = atts.getValue("id");
		if (id == null) {
			System.err.println("Failed to parse: task id");
			id = "DefaultID";
		}
		String taskName = atts.getValue("name");
		if (taskName == null) {
			System.err.println("Failed to parse: task " + id + "'s name");
			taskName = "Unknown";
		}
		String oh = atts.getValue("onHold");
		boolean onHold = false;
		if (oh == null) {
			System.err.println("Failed to parse: task " + id + "'s on hold");
		} else {
			onHold = (oh.equals("true"));
		}
		String c = atts.getValue("complete");
		boolean complete = false;
		if (c == null) {
			System.err.println("Failed to parse: task " + id + "'s complete");
		} else {
			complete = (c.equals("true"));
		}
		Calendar dueDate = null;
		try {
			dueDate = new GregorianCalendar();
			dueDate.setTime(DateFormat.getDateTimeInstance(DateFormat.MEDIUM,
					DateFormat.MEDIUM).parse(atts.getValue("dueDate")));
		} catch (ParseException e) {
			System.err
			.println("Failed to parse: task " + id + "'s due date invalid");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no due date for task " + id);
		}
		double priority = 0.0;
		try {
			priority = Double.valueOf(atts.getValue("priority"));
		} catch (NumberFormatException e) {
			System.err
			.println("Failed to parse: task " + id + "'s priority invalid");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no priority for task " + id);
		}
		
		long time = this.extractTime(atts);
		this.engine.changeTask(id, taskName, onHold, complete, dueDate,
				priority, time);
	}

	/**
	 * Deletes a notification with the given attributes.
	 * 
	 * @param atts
	 *            the vector of attributes of this notification
	 */
	private void deleteNotification(Attributes atts) {
		String id = atts.getValue("id");
		if (id == null) {
			System.err.println("Failed to parse: notification id");
			id = "DefaultID";
		}
		long time = this.extractTime(atts);
		this.engine.deleteNotification(id, time);
	}

	/**
	 * Deletes a task with the given attributes.
	 * 
	 * @param atts
	 *            the vector of attributes of this task
	 */
	private void deleteTask(Attributes atts) {
		String id = atts.getValue("id");
		if (id == null) {
			System.err.println("Failed to parse: task id");
			id = "DefaultID";
		}
		long time = this.extractTime(atts);
		this.engine.deleteTask(id, time);
	}

	/**
	 * Extracts the time to add from the attributes, either as an offset from
	 * now or an absolute time.
	 * 
	 * @param atts
	 *            the vector of attributes to extract the time from
	 */
	private long extractTime(Attributes atts) {
		long time = 0;
		try {
			String ts = atts.getValue("time");

			// Offset
			if (ts.substring(0, 1).equals("+")) {
				time = Long.valueOf(ts.substring(1));
			}

			// Absolute time
			else {
				time = (DateFormat.getDateTimeInstance(DateFormat.MEDIUM,
						DateFormat.MEDIUM).parse(ts)).getTime();
				time -= Calendar.getInstance().getTimeInMillis();
			}
		} catch (ParseException e) {
			System.err.println("Failed to parse: invalid time specified");
		} catch (NumberFormatException e) {
			System.err.println("Failed to parse: invalid time specified");
		} catch (NullPointerException e) {
			System.err.println("Failed to parse: no time specified");
		}
		return time;
	}

	/**
	 * Parses the start element of an XML tag and acts accordingly.
	 * 
	 * @see org.xml.sax.helpers.DefaultHandler#startElement(java.lang.String,
	 *      java.lang.String, java.lang.String, org.xml.sax.Attributes)
	 */
	@Override
	public void startElement(String uri, String name, String qName,
			Attributes atts) {

		// Add a notification at the specified time
		if (qName == "addNotification") {
			this.addNotification(atts);
		}

		// Change a notification's priority
		else if (qName == "changeNotification") {
			this.changeNotification(atts);
		}

		// Delete a notification
		else if (qName == "deleteNotification") {
			this.deleteNotification(atts);
		}

		// Add a task
		else if (qName == "addTask") {
			this.addTask(atts);
		}

		// Change a task
		else if (qName == "changeTask") {
			this.changeTask(atts);
		}

		// Delete a task
		else if (qName == "deleteTask") {
			this.deleteTask(atts);
		}
	}
}
