/* File: AbstractManager.java
 *
 * Contains class AbstractManager
 *
 * Author: Will Haines
 */

package edu.cmu.hcii.calo.manager;

import java.io.Serializable;
import java.util.Observable;

/**
 * Represents a Manager class that manages some kind of entity object (such as tasks, notifications,
 * etc.) Managers must be able to assign unique IDs to their managed entities when they are added to
 * the manager, so that the entities can be serialized and deserialized without equals() and
 * hashCode() becoming inaccurate.
 * 
 * @author Will Haines
 * 
 */
public class AbstractManager extends Observable implements Serializable {

	/** Prevent serialization collisions. */
	private static final long serialVersionUID = -388768069922935616L;

	/**
	 * A way to generate unique ids for objects managed by this manager. We start at 1000 to make it
	 * obvious that everything got initialized correctly.
	 */
	private int nextId = 1000;

	/**
	 * Constructs an abstract manager.
	 */
	public AbstractManager() {
		super();
	}

	/**
	 * Generates the next unique id for an managed object by incrementing.
	 * 
	 * @return the next id in sequence
	 */
	protected int getNextId() {
		return this.nextId++ ;
	}

}
