/* File: Message.java
 *
 * Contains class Message
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.messagePassing;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Observable;

/**
 * Represents a message passed between various parts of the system. Messages are sent by Observable
 * instances and passed as the parameter to the Observable#notifyObservers(Object) method.
 * 
 * @author Brian Ellis
 * 
 */
public abstract class Message implements Serializable {

	/**
	 * The type of this message.
	 */
	protected MessageType messageType;

	/** The object that sent this message. */
	private Observable sender;

	/**
	 * Any message-specific data associated with this message.
	 */
	private Map<String, Object> userInfo;

	/**
	 * Constructs a new Message with an empty userInfo map.
	 * 
	 * @param sender the Observable that has sent this message
	 * @param type the type of this message
	 */
	public Message(Observable sender, MessageType type) {
		this(sender, type, new HashMap<String, Object>());
	}

	/**
	 * Constructs a new Message.
	 * 
	 * @param sender the Observable that has sent this message
	 * @param type the type of this message
	 * @param userInfo the map of message-specific data associated with this message
	 */
	public Message(Observable sender, MessageType type, Map<String, Object> userInfo) {
		super();
		assert sender != null : "this message has a null sender";
		this.sender = sender;
		this.messageType = type;
		this.userInfo = userInfo;
	}

	/**
	 * Accessor method for messageType
	 * 
	 * @return the value of messageType
	 */
	public MessageType getMessageType() {
		return this.messageType;
	}

	/**
	 * Accessor method for sender
	 * 
	 * @return the value of sender
	 */
	public Observable getSender() {
		return this.sender;
	}

	/**
	 * Accessor method for userInfo
	 * 
	 * @return the value of userInfo
	 */
	public Map<String, Object> getUserInfo() {
		return this.userInfo;
	}
}
