/* File: MessageTarget.java
 *
 * Contains class MessageTarget
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.messagePassing;

import java.util.Observable;
import java.util.Observer;

/**
 * Represents an object that can be the target of a Message. MessageTarget implements an
 * onMessageReceived method that must be implemented by subclasses to process the messages they
 * receive.
 * 
 * @author Brian Ellis
 */
public abstract class MessageTarget extends Observable implements Observer {

	/**
	 * Should be implemented by implementing classes to handle specific messages
	 * 
	 * @param sender the sender of this message
	 * @param msg the message being sent
	 */
	public abstract void onMessageReceived(Observable sender, Message msg);

	/**
	 * @see java.util.Observer#update(java.util.Observable, java.lang.Object)
	 */
	public final void update(Observable o, Object arg) {
		assert arg != null : "received an Observable update with a null Message.";
		assert arg instanceof Message : "received an Observable update that was not a Message.";
		this.onMessageReceived(o, (Message)arg);
	}
}
