/* File: TasklikeObjectMessage.java
 *
 * Contains class TasklikeObjectMessage
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.messagePassing;

import java.util.Map;
import java.util.Observable;

import edu.cmu.hcii.calo.manager.AbstractManager;
import edu.cmu.hcii.calo.model.TasklikeObject;

/**
 * A type of Message that pertains to the modification and management of TasklikeObject instances.
 * 
 * @author Brian Ellis
 */
public class TasklikeObjectMessage extends Message {

	/**
	 * The possible types of a TasklikeObjectMessage
	 * 
	 * @author Brian Ellis
	 * 
	 */
	public enum TasklikeObjectMessageType implements MessageType {
		/** The TasklikeObject has just been added to the manager. */
		TASKLIKE_OBJECT_ADDED,
		/** The TasklikeObject has just been removed from the manager. */
		TASKLIKE_OBJECT_REMOVED,
	}

	/** To prevent serialization collisions. */
	private static final long serialVersionUID = 6128954924460994128L;

	/**
	 * The TasklikeObject to which this message pertains.
	 */
	private TasklikeObject tasklikeObject;

	/**
	 * Constructs a TasklikeObjectMessage for the given manager, message type, and TasklikeObject.
	 * 
	 * @param manager the manager sending the message
	 * @param type the type of the message
	 * @param t the TasklikeObject to which the message pertains
	 */
	public TasklikeObjectMessage(AbstractManager manager,
			TasklikeObjectMessageType type,
			TasklikeObject t) {
		this(manager, type);
		this.tasklikeObject = t;
	}

	/**
	 * Constructs a TasklikeObjectMessage for the given manager, message type, TasklikeObject, and
	 * user info map.
	 * 
	 * @param manager the manager sending the message
	 * @param type the type of the message
	 * @param t the TasklikeObject to which the message pertains
	 * @param userInfo the user info map for this message
	 */
	public TasklikeObjectMessage(AbstractManager manager,
			TasklikeObjectMessageType type,
			TasklikeObject t,
			Map<String, Object> userInfo) {
		this(manager, type, userInfo);
		this.tasklikeObject = t;
	}

	/**
	 * Private constructor. Use TasklikeObjectMessage#TaskManagedObjectMessage(Observable,
	 * MessageType, TasklikeObject) instead.
	 * 
	 * @param sender the object that sent this message
	 * @param type the type of this message
	 */
	private TasklikeObjectMessage(Observable sender, MessageType type) {
		super(sender, type);
	}

	/**
	 * Private constructor. Use TasklikeObjectMessage#TaskManagedObjectMessage(Observable,
	 * MessageType, TasklikeObject, Map) instead.
	 * 
	 * @param sender the object that sent this message
	 * @param type the type of this message
	 * @param userInfo the map of message-specific data associated with this message
	 */
	private TasklikeObjectMessage(Observable sender, MessageType type, Map<String, Object> userInfo) {
		super(sender, type, userInfo);
	}

	/**
	 * Accessor method for tasklikeObject
	 * 
	 * @return the value of tasklikeObject
	 */
	public TasklikeObject getTasklikeObject() {
		return this.tasklikeObject;
	}
}
