/* File: HistoryItem.java
 *
 * Contains class HistoryItem
 *
 * Author: Will Haines
 */

package edu.cmu.hcii.calo.model;

import java.util.Calendar;

import edu.cmu.hcii.calo.messagePassing.Message;

/**
 * An item that goes in the history manager.
 * 
 * @author Will Haines
 */
public class HistoryItem extends ManagedObject {

	/** To prevent serialization collisions. */
	private static final long serialVersionUID = 3492496787223142434L;

	/** The message that generated this history item */
	private Message message;

	/**
	 * Constructs a HistoryItem with the given message and CALO added status.
	 * 
	 * @param message the message associated with this HistoryItem
	 * @param caloAdded \c true if this item was added by CALO, \c false otherwise.
	 */
	public HistoryItem(Message message, boolean caloAdded) {
		this.message = message;
		this.setDateAdded(Calendar.getInstance());
		this.setCaloAdded(caloAdded);
	}

	/**
	 * A getter for message.
	 * 
	 * @return the message that generated this item
	 */
	public Message getMessage() {
		return this.message;
	}
}
