/* File: Pack.java
 *
 * Contains class Pack
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.model;

import edu.cmu.hcii.calo.manager.PackManager;

/**
 * Represents a Pack, a set of resources relevant to some other object that
 * persists in a view.
 * 
 * @author Brian Ellis
 * 
 */
public class Pack extends ManagedObject {

	/** To prevent serialization collisions */
	private static final long serialVersionUID = 865619078372009742L;

	/** This pack's resources */
	private ResourceList resources;

	/**
	 * Accessor method for resources
	 * 
	 * @return the value of resources
	 */
	public ResourceList getResources() {
		return this.resources;
	}

	/**
	 * Setter method for resources.
	 * 
	 * @param resources
	 *            the resources to set
	 */
	public void setResources(ResourceList resources) {
		if (resources == null) {
			throw new IllegalArgumentException(
					"Packs cannot have null resource lists.");
		}
		ResourceList oldResources = this.resources;
		this.resources = resources;
		if (this.isManaged()) {
			PackManager.getManager().notePackChanged(this, oldResources,
					this.resources);
		}
	}

}
