/* File: KeyFunctor.java
 *
 * Contains class KeyFunctor
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.model.sorting;

/**
 * Represents a functor (an object that is used as a function) that returns a
 * sort key given an object of the type being sorted in a MutableSortedSet.
 * 
 * @author Brian Ellis
 */
public abstract class KeyFunctor<E> {

	/**
	 * Should be implemented to return a sort key (as a double) based on the
	 * given item's data. Note that unlike a compareTo method, this should
	 * <i>not</i> return a sort <i>ordering</i>, but rather a key by which
	 * this object will be sorted. Specifically, the set will be sorted in order
	 * from highest sort key to lowest.
	 * 
	 * @param item
	 *            the item to generate a key for
	 * @return the key, as a double
	 */
	public abstract double getKey(E item);
}