/* File: ThinkAloud.java
 *
 * Contains class ThinkAloud
 *
 * Author: Will Haines
 */

package edu.cmu.hcii.calo.thinkaloud;

import java.io.File;
import java.util.Calendar;
import java.util.GregorianCalendar;

import javax.swing.UIManager;

import edu.cmu.hcii.calo.SidebarWindow;
import edu.cmu.hcii.calo.engine.WizardOfOzEngine;
import edu.cmu.hcii.calo.manager.ScheduleManager;
import edu.cmu.hcii.calo.manager.TaskManager;
import edu.cmu.hcii.calo.model.PendingState;
import edu.cmu.hcii.calo.model.Resource;
import edu.cmu.hcii.calo.model.ResourceList;
import edu.cmu.hcii.calo.model.ScheduleItem;
import edu.cmu.hcii.calo.model.Task;

/**
 * The main runner for ThinkAlouds.
 * 
 * @author Will Haines
 */
public class ThinkAloud {

	/**
	 * The sidebar.
	 */
	private static SidebarWindow theSidebar;

	/**
	 * Runs a the Wizard of Oz engine and task viewer for think aloud 3.
	 * 
	 * @param args
	 *            command-line args; don't bother passing any
	 */
	public static void main(String[] args) {

		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			System.err.println("Error setting native LAF: " + e);
		}

		// Set up the sidebar with the right stuff
		TaskManager taskManager = TaskManager.getManager();

		Task finishXEPresentation = new Task("Finish XE Presentation", false);
		finishXEPresentation.setPriority(80.0);
		finishXEPresentation.setDueDate(new GregorianCalendar(2007, 7, 13));
		Resource xEResource = new Resource(new File(
				"RequiredFiles/XE Presentation_v2.ppt"));
		ResourceList xEList = new ResourceList();
		xEList.add(xEResource);
		finishXEPresentation.setResources(xEList);
		finishXEPresentation.addTag("fix formatting");
		taskManager.addTasklikeObject(finishXEPresentation);

		Task evaluationSheet = new Task("Evaluation Sheet", false);
		evaluationSheet.setPriority(60.0);
		evaluationSheet.setDueDate(new GregorianCalendar(2007, 7, 16));
		Resource evalResource = new Resource(new File(
				"RequiredFiles/Evaluation_summer07.doc"));
		ResourceList evalList = new ResourceList();
		evalList.add(evalResource);
		evaluationSheet.setResources(evalList);
		taskManager.addTasklikeObject(evaluationSheet);

		Task expenseReport = new Task("Expense Report", false);
		expenseReport.setPriority(50.0);
		Resource expenseResource = new Resource(new File(
				"RequiredFiles/Boston Expenses.xls"));
		ResourceList expenseList = new ResourceList();
		expenseList.add(expenseResource);
		expenseReport.setResources(expenseList);
		taskManager.addTasklikeObject(expenseReport);

		Task salesReport = new Task("Sales Report", false);
		PendingState salesPending = new PendingState();
		salesPending.setPending(true);
		salesReport.setPendingState(salesPending);
		taskManager.addTasklikeObject(salesReport);

		Task replyToDiane = new Task("Reply to Diane", false);
		replyToDiane.setComplete(true);
		replyToDiane.setDateCompleted(Calendar.getInstance());
		taskManager.addTasklikeObject(replyToDiane);

		Task summaryReport = new Task("Send Summary Report", false);
		summaryReport.setComplete(true);
		summaryReport.setDateCompleted(Calendar.getInstance());
		taskManager.addTasklikeObject(summaryReport);

		Task reviewResearch = new Task("Review Research", false);
		reviewResearch.setComplete(true);
		reviewResearch.setDateCompleted(Calendar.getInstance());
		taskManager.addTasklikeObject(reviewResearch);

		Task cIFReport = new Task("CIF Report", false);
		cIFReport.setComplete(true);
		cIFReport.setDateCompleted(Calendar.getInstance());
		taskManager.addTasklikeObject(cIFReport);

		Calendar meetingWithJimStart = Calendar.getInstance();
		meetingWithJimStart.set(Calendar.HOUR_OF_DAY, 15);
		meetingWithJimStart.set(Calendar.MINUTE, 0);
		meetingWithJimStart.set(Calendar.SECOND, 0);

		Calendar confCallWithLindsayStart = Calendar.getInstance();
		confCallWithLindsayStart.set(Calendar.HOUR_OF_DAY, 11);
		confCallWithLindsayStart.set(Calendar.MINUTE, 0);
		confCallWithLindsayStart.set(Calendar.SECOND, 0);

		Calendar confCallWithLindsayEnd = Calendar.getInstance();
		confCallWithLindsayEnd.set(Calendar.HOUR_OF_DAY, 12);
		confCallWithLindsayEnd.set(Calendar.MINUTE, 30);
		confCallWithLindsayEnd.set(Calendar.SECOND, 0);

		Calendar systemMaintenanceStart = Calendar.getInstance();
		systemMaintenanceStart.set(Calendar.HOUR_OF_DAY, 23);
		systemMaintenanceStart.set(Calendar.MINUTE, 0);
		systemMaintenanceStart.set(Calendar.SECOND, 0);

		Calendar systemMaintenanceEnd = Calendar.getInstance();
		systemMaintenanceEnd.add(Calendar.DAY_OF_MONTH, 1);
		systemMaintenanceEnd.set(Calendar.HOUR_OF_DAY, 2);
		systemMaintenanceEnd.set(Calendar.MINUTE, 0);
		systemMaintenanceEnd.set(Calendar.SECOND, 0);

		Calendar presentationStart = Calendar.getInstance();
		presentationStart.set(Calendar.MONTH, 7);
		presentationStart.set(Calendar.DAY_OF_MONTH, 2);
		presentationStart.set(Calendar.HOUR_OF_DAY, 15);
		presentationStart.set(Calendar.MINUTE, 30);

		Calendar presentationEnd = (Calendar) presentationStart.clone();
		presentationEnd.set(Calendar.HOUR_OF_DAY, 16);

		ScheduleItem confCallWithLindsay = new ScheduleItem(false,
				confCallWithLindsayStart, confCallWithLindsayEnd);
		confCallWithLindsay.setName("Conference call with Lindsay");

		ScheduleItem systemMaintenance = new ScheduleItem(false,
				systemMaintenanceStart, systemMaintenanceEnd);
		systemMaintenance.setName("System Maintenance");

		Calendar momentarily = Calendar.getInstance();
		momentarily.add(Calendar.MINUTE, 1);

		Calendar aBitLater = Calendar.getInstance();
		aBitLater.add(Calendar.MINUTE, 2);

		ScheduleItem testItem = new ScheduleItem(false, momentarily, aBitLater);
		testItem.setName("Test item");

		ScheduleItem presentation = new ScheduleItem(false, presentationStart,
				presentationEnd);
		presentation.setName("CALO Final Presentation!");

		ScheduleManager.getManager().addItem(confCallWithLindsay);
		ScheduleManager.getManager().addItem(systemMaintenance);
		ScheduleManager.getManager().addItem(presentation);
		// ScheduleManager.getManager().addItem(testItem);

		// Let's see it
		ThinkAloud.theSidebar = new SidebarWindow(false);
		ThinkAloud.theSidebar.setVisible(true);
		WizardOfOzEngine.getEngine().startInputReadingLoop();
	}
}
