/* File: TimeSpinner.java
 *
 * Contains class TimeSpinner
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view;

import java.awt.Insets;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

import javax.swing.JFormattedTextField;
import javax.swing.JSpinner;
import javax.swing.SpinnerDateModel;
import javax.swing.text.DateFormatter;
import javax.swing.text.DefaultFormatterFactory;

/**
 * A spinner subclass that uses a date/time formatter to allow the user to spin through times.
 * 
 * @author Brian Ellis
 * 
 */
public class TimeSpinner extends JSpinner {

	/** Prevent serialization collisions. */
	private static final long serialVersionUID = 1192169559594560063L;

	/** The formatter for this spinner. */
	private DateFormatter formatter;

	/**
	 * Constructs a TimeSpinner initialized to the current time.
	 */
	public TimeSpinner() {
		SimpleDateFormat dateFormat = new SimpleDateFormat("h:mm a");
		GregorianCalendar calendar = new GregorianCalendar();
		Date now = calendar.getTime();
		SpinnerDateModel dateModel = new SpinnerDateModel(now, null, null, Calendar.MINUTE);
		this.setModel(dateModel);
		JFormattedTextField tf = ((JSpinner.DefaultEditor)this.getEditor()).getTextField();
		DefaultFormatterFactory factory = (DefaultFormatterFactory)tf.getFormatterFactory();
		this.formatter = (DateFormatter)factory.getDefaultFormatter();
		this.formatter.setFormat(dateFormat);
		tf.setMargin(new Insets(0, 5, 0, 0));
		this.formatter.install(tf);
	}
}
