/* File: NotificationState.java
 *
 * Contains class NotificationState
 *
 * Author: Will Haines
 */

package edu.cmu.hcii.calo.view.notification.support;

import edu.cmu.hcii.calo.model.Notification;

/**
 * Represents a particular property within the state of a Notification. When NotificationPaneView
 * generates PropertyChangedEvents with a name of
 * NotificationViewPropertyNames#NOTIFICATION_STATE_PROPERTY_NAME, the old and new values passed in
 * the event will be NotificationState objects representing what has changed in what notification.
 * 
 * @author Will Haines
 * 
 */
public class NotificationState {

	/**
	 * Represents a particular property of a notification that can change.
	 * 
	 * @author Will Haines
	 * 
	 */
	public enum NotificationStateProperty {
		NOTIFICATION_DELETED,
	}

	/**
	 * The notifications to which this state pertains.
	 */
	private Notification notification;

	/**
	 * The property that we are concerned with.
	 */
	private NotificationStateProperty property;

	/**
	 * The value of that property.
	 */
	private Object value;

	/**
	 * Constructs a NotificationState for the given notification, noting that \p property has a
	 * value of \p value.
	 * 
	 * @param notification the notification to which this state pertains
	 * @param property the property that we are concerned with
	 * @param value the value of that property
	 */
	public NotificationState(Notification notification,
			NotificationStateProperty property,
			Object value) {
		this.notification = notification;
		this.property = property;
		this.value = value;
	}

	/**
	 * Gets the Notification for this NotificationState.
	 * 
	 * @return the Notification
	 */
	public Notification getNotification() {
		return this.notification;
	}

	/**
	 * Gets the property for this NotificationState.
	 * 
	 * @return the property
	 */
	public NotificationStateProperty getProperty() {
		return this.property;
	}

	/**
	 * The value for this NotificationState.
	 * 
	 * @return the Notification
	 */
	public Object getValue() {
		return this.value;
	}
}
