/* File: NotificationViewPropertyNames.java
 *
 * Contains class NotificationViewPropertyNames
 *
 * Author: Will Haines
 */

package edu.cmu.hcii.calo.view.notification.support;

/**
 * The property names that are defined for PropertyChangeEvents emanating from the
 * NotificationPaneView.
 * 
 * @author Will Haines
 * 
 */
public class NotificationViewPropertyNames {

	/**
	 * Fired whenever a NotificationView expands or collapses (but does not indicate which one). The
	 * old and new values will be booleans, \c true meaning expanded, \c false meaning not expanded.
	 */
	public static final String NOTIFICATION_EXPANDED = "NotificationExpanded";

	/**
	 * Fired whenever the state of a NotificationView changes, where the parameters of a state are
	 * defined in the NotificationState class. The old and new values will be NotificationStates,
	 * both of which will pertain to the same Notification. Note that firing a
	 * NOTIFICATION_STATE_PROPERTY_NAME property change does NOT imply that the model has changed;
	 * it is the responsibility of the controller to update the model in response to these events.
	 */
	public static final String NOTIFICATION_STATE = "NotificationState";

	/**
	 * Fired whenever the state of a NotificationGroupView changes, where the parameters of a state
	 * are defined in the NotificationGroupState class. The old and new values will be
	 * NotificationGroupStates, both of which will pertain to the same Notification group. Note that
	 * firing a NOTIFICATION_GROUP_STATE_PROPERTY_NAME property change does NOT imply that the model
	 * has changed; it is the responsibility of the controller to update the model in response to
	 * these events.
	 */
	public static final String NOTIFICATION_GROUP_STATE = "NotificationGroupState";

	/**
	 * Fired whenever the order of a NotificationView relative to other NotificationViews changes.
	 * The old value will be \c null, and the new value will be a List of three adjacent
	 * Notification objects in the order they now appear in the list, with the reordered
	 * notification in the middle. Either the first or last Notification in the list may be \c null,
	 * which indicates that the middle Notification should be at the beginning or end of the list,
	 * respectively.
	 */
	public static final String NOTIFICATION_ORDER = "NotificationOrder";

	/**
	 * Fired whenever the user requests a notification group outside of the mini bar to move.
	 */
	public static final String NOTIFICATION_OUTSIDE_MOVE = "NotificationOutsideMove";

	/**
	 * Fired whenever the user changes the notification group outside of the mini bar.
	 */
	public static final String NOTIFICATION_OUTSIDE_CHANGE = "NotificationOutsideChange";
}
