/* File: DraggyBit.java
 *
 * Contains class DraggyBit
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.panes;

import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.GradientPaint;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.SystemColor;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.geom.Point2D;

import javax.swing.JComponent;

/**
 * A control that allows the user to resize its associated pane by dragging it.
 * 
 * It's called a DraggyBit because it's a bit (as opposed to a bob), and you drag it.
 * 
 * @author Brian Ellis
 * 
 */
public class DraggyBit extends JComponent {

	/** Prevent serialization collisions */
	private static final long serialVersionUID = 818156187826856495L;

	/**
	 * The point at which the user first clicked the draggy bit.
	 */
	private Point clickPoint;

	/**
	 * Constructs a DraggyBit.
	 */
	public DraggyBit() {
		this.setCursor(Cursor.getPredefinedCursor(Cursor.S_RESIZE_CURSOR));
		final MouseAdapter mouseAdapter = new MouseAdapter() {

			@SuppressWarnings("synthetic-access")
			@Override
			public void mouseDragged(MouseEvent e) {
				Point newPoint = e.getPoint();
				int deltaY = newPoint.y - DraggyBit.this.clickPoint.y;
				Dimension currentSize = DraggyBit.this.getParent().getPreferredSize();
				Dimension desiredSize =
					new Dimension(	DraggyBit.this.getParent().getPreferredSize().width,
									DraggyBit.this.getParent().getPreferredSize().height + deltaY);

				DraggyBit.this.firePropertyChange("DesiredPaneSize", currentSize, desiredSize);
				// DraggyBit.this.getParent().setPreferredSize(desiredSize);
				// revalidate();

				// DraggyBit.this.clickPoint = new Point(e.getPoint().x, e.getPoint().y - deltaY);
			}

			@SuppressWarnings("synthetic-access")
			@Override
			public void mousePressed(MouseEvent e) {
				DraggyBit.this.clickPoint = e.getPoint();
			}

		};
		this.addMouseListener(mouseAdapter);
		this.addMouseMotionListener(mouseAdapter);
	}

	/**
	 * Paints the draggy bit.
	 * 
	 * @param graphics the graphics to paint with
	 */
	@Override
	protected void paintComponent(Graphics graphics) {
		super.paintComponent(graphics);
		Graphics2D g = (Graphics2D)graphics;
		g = (Graphics2D)g.create();

		g.setPaint(new GradientPaint(	new Point2D.Double(0, 0),
										SystemColor.controlHighlight,
										new Point2D.Double(0, this.getHeight()),
										SystemColor.controlShadow));
		g.fillRect(0, 0, this.getWidth(), this.getHeight());

		g.dispose();
	}

	/**
	 * Returns the preferred size of this component if it's been set, otherwise calculates it.
	 */
	@Override
	public Dimension getPreferredSize() {
		if (this.isPreferredSizeSet()) {
			return super.getPreferredSize();
		} else {
			return new Dimension(super.getPreferredSize().width, 4);
		}
	}

}
