/* File: RelevantStuffPaneView.java
 *
 * Contains class RelevantStuffPaneView
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.relevantstuff;

import java.awt.Font;
import java.awt.SystemColor;
import java.io.File;

import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.SwingConstants;
import javax.swing.filechooser.FileSystemView;

import edu.cmu.hcii.calo.view.CALOComponent;
import edu.cmu.hcii.calo.view.JLinkButton;
import edu.cmu.relativelayout.BindingMaker;
import edu.cmu.relativelayout.RelativeConstraints;
import edu.cmu.relativelayout.RelativeLayout;

/**
 * The "CALO Suggestions" pane in the sidebar, which has long internally been known as the "Relevant
 * Stuff" pane. This doesn't do anything other than sit there and look like a pane, since the logic
 * to actually change it in response to window focus changes is nowhere to be found. Accordingly,
 * the class is pretty small.
 * 
 * @author Brian Ellis
 * 
 */
public class RelevantStuffPaneView extends CALOComponent {

	/** Prevent serialization collisions. */
	private static final long serialVersionUID = 8893278749071196266L;

	/**
	 * Constructs a RelevantStuffPaneView.
	 */
	public RelevantStuffPaneView() {
		this.setup();
	}

	/**
	 * Sets up the visual appearance of this pane.
	 */
	private void setup() {
		this.setOpaque(true);
		this.setBackground(SystemColor.text);
		this.setLayout(new RelativeLayout());

		JLabel relevantResourcesLabel = new JLabel("Relevant Resources:");
		relevantResourcesLabel.setFont(relevantResourcesLabel.getFont().deriveFont(Font.BOLD));

		JLinkButton bostonExpensesLabel = new JLinkButton("Boston Expenses.xls");
		Icon systemIcon = null;
		File file = new File("C:/Boston Expenses.xls");
		if (file.exists()) {
			systemIcon = FileSystemView.getFileSystemView().getSystemIcon(file);
			bostonExpensesLabel.setIcon(systemIcon);
		}
		bostonExpensesLabel.setHorizontalAlignment(SwingConstants.LEFT);

		JLinkButton xePresentationLabel = new JLinkButton("XE Presentation_v2.ppt");
		file = new File("C:/XE Presentation_v2.ppt");
		if (file.exists()) {
			systemIcon = FileSystemView.getFileSystemView().getSystemIcon(file);
			xePresentationLabel.setIcon(systemIcon);
		}
		xePresentationLabel.setHorizontalAlignment(SwingConstants.LEFT);

		JLabel caloActionsLabel = new JLabel("CALO Actions:");
		caloActionsLabel.setFont(caloActionsLabel.getFont().deriveFont(Font.BOLD));

		JLinkButton automateFormLabel = new JLinkButton("Automate form");

		BindingMaker bm = new BindingMaker(4, 4, 4, 4, 0, 0);

		this.add(relevantResourcesLabel, new RelativeConstraints(bm.topEdge(), bm.leftEdge()));
		this.add(bostonExpensesLabel, new RelativeConstraints(	bm.below(relevantResourcesLabel),
																bm.leftEdge()));
		this.add(xePresentationLabel, new RelativeConstraints(	bm.below(bostonExpensesLabel),
																bm.leftEdge()));

		this.add(caloActionsLabel, new RelativeConstraints(	bm.below(xePresentationLabel),
															bm.leftEdge()));
		this.add(automateFormLabel, new RelativeConstraints(bm.below(caloActionsLabel),
															bm.leftEdge()));

	}
}
