/* File: ResourceListCellRenderer.java
 *
 * Contains class ResourceListCellRenderer
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.resources;

import java.awt.Component;

import javax.swing.DefaultListCellRenderer;
import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.SwingConstants;
import javax.swing.filechooser.FileSystemView;

import edu.cmu.hcii.calo.model.Resource;

/**
 * Renders cells for the resource list. This renderer displays the appropriate icon for the file
 * next to the file name.
 * 
 * @author Brian Ellis
 * 
 */
public class ResourceListCellRenderer extends DefaultListCellRenderer {

	/**
	 * Prevent serialization collisions.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Returns the component that should be used to render the contents of the list cell. In this
	 * case, we take the normal cell (which is a JLabel) and add the icon for each resource to the
	 * left of the name of the resource.
	 * 
	 * @param list the list being painted
	 * @param value the Resource represented by this particular cell
	 * @param index the index of this item in the list
	 * @param isSelected whether the current cell is selected
	 * @param cellHasFocus whether the current cell has focus
	 */
	@Override
	public Component getListCellRendererComponent(JList list,
			Object value,
			int index,
			boolean isSelected,
			boolean cellHasFocus) {

		Component c =
			super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);

		assert c instanceof JLabel : "default list cell was not a JLabel.  Interesting.";

		JLabel label = (JLabel)c;

		assert value instanceof Resource : "resource list item was not a resource!";
		Resource rsrc = (Resource)value;

		assert rsrc.getAssociatedFile() != null : "resource had no associated file.";

		String fileName = rsrc.getAssociatedFile().getName();
		label.setText(fileName);

		if (rsrc.getAssociatedFile().exists()) {
			Icon systemIcon =
				FileSystemView.getFileSystemView().getSystemIcon(rsrc.getAssociatedFile());
			label.setIcon(systemIcon);
			label.setHorizontalAlignment(SwingConstants.LEFT);
		}

		label.setToolTipText("<html><p><strong>" + fileName + "</strong></p>"
				+ "<p>Double-click to open this resource.</p></html>");

		return label;
	}
}
