/* File: ResourceListModel.java
 *
 * Contains class ResourceListModel
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.resources;

import javax.swing.AbstractListModel;

import edu.cmu.hcii.calo.model.Task;

/**
 * Defines the model for the resource list.
 * 
 * @author Brian Ellis
 * 
 */
public class ResourceListModel extends AbstractListModel {

	/**
	 * Prevent serialization collisions.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * The task whose resources this list represents.
	 */
	private Task task;

	/**
	 * Creates a new ResourceListModel for the resources of the given task.
	 * 
	 * @param value the task whose resources we're showing
	 */
	public ResourceListModel(Task value) {
		this.task = value;
	}

	/**
	 * Gets the resource at the given index in the list.
	 * 
	 * @param i the index
	 */
	@SuppressWarnings("synthetic-access")
	public Object getElementAt(int i) {
		return this.task.getResources().at(i);
	}

	/**
	 * Returns the size of this list.
	 */
	@SuppressWarnings("synthetic-access")
	public int getSize() {
		return this.task.getResources().size();
	}

	/**
	 * Tells the list to update its contents because they might have changed.
	 */
	public void updateList() {
		this.fireContentsChanged(this, 0, this.getSize());
	}
}
