/* File: CompleteBox.java
 *
 * Contains class CompleteBox
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.task;

import java.awt.Dimension;

import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JCheckBox;
import javax.swing.SwingConstants;

/**
 * A check box for use with the TaskView. This is different from a standard check box in that it has
 * a transparent background and does not expect a text label (and will, in fact, complain if you try
 * to set one).
 * 
 * @note This class is no longer used, because we are now using an image for the complete checkboxes
 *       due to user confusion over whether the check box was intended to select the task (as in
 *       many Web interfaces). It is being left in for completeness, however.
 * 
 * @deprecated
 * 
 * @author Brian Ellis
 * 
 */
@SuppressWarnings("serial")
public class CompleteBox extends JCheckBox {

	/**
	 * Constructs a CompleteBox with no action.
	 */
	public CompleteBox() {
		super();
		setup();
	}

	/**
	 * Constructs a CompleteBox with the given action.
	 * 
	 * @param a the action to assign
	 */
	public CompleteBox(Action a) {
		super(a);
		setup();
	}

	/**
	 * Constructs a CompleteBox with the given icon.
	 * 
	 * @param icon the icon to use
	 */
	public CompleteBox(Icon icon) {
		super(icon);
		setup();
	}

	/**
	 * Constructs a CompleteBox with the given icon and initial selection state.
	 * 
	 * @param icon the icon to use
	 * @param selected the initial selection state
	 */
	public CompleteBox(Icon icon, boolean selected) {
		super(icon, selected);
		setup();
	}

	/**
	 * Private superclass constructor. Do not use.
	 * 
	 * @param text text label
	 */
	@SuppressWarnings("unused")
	private CompleteBox(String text) {
	// Intentionally left blank
	}

	/**
	 * Private superclass constructor. Do not use.
	 * 
	 * @param text text label
	 * @param selected initial selection state
	 */
	@SuppressWarnings("unused")
	private CompleteBox(String text, boolean selected) {
	// Intentionally left blank
	}

	/**
	 * Private superclass constructor. Do not use.
	 * 
	 * @param text text label
	 * @param icon icon
	 */
	@SuppressWarnings("unused")
	private CompleteBox(String text, Icon icon) {
	// Intentionally left blank
	}

	/**
	 * Private superclass constructor. Do not use.
	 * 
	 * @param text text label
	 * @param icon icon
	 * @param selected initial selection state
	 */
	@SuppressWarnings("unused")
	private CompleteBox(String text, Icon icon, boolean selected) {
	// Intentially left blank
	}

	/**
	 * Throws an UnsupportedOperationException because CompleteBoxes cannot have text labels.
	 * 
	 * @param text the text to (ostensibly) set
	 * 
	 * @see javax.swing.AbstractButton#setText(java.lang.String)
	 */
	@Override
	public void setText(String text) {
		throw new UnsupportedOperationException("CompleteBoxes cannot have text labels.");
	}

	/**
	 * Fires the state change event, and then sets the tooltip text of the button appropriately.
	 * 
	 * @see javax.swing.AbstractButton#fireStateChanged()
	 */
	@Override
	protected void fireStateChanged() {
		super.fireStateChanged();
		if (this.isSelected()) {
			this.setToolTipText("Click to mark this task as not completed.");
		} else {
			this.setToolTipText("Click to mark this task as completed.");
		}
	}

	/**
	 * Sets up the visual appearance of this view.
	 */
	private void setup() {
		this.setPreferredSize(new Dimension(16, 16));
		this.setHorizontalAlignment(SwingConstants.CENTER);
		this.setVerticalAlignment(SwingConstants.CENTER);
		this.setOpaque(false);
		this.setToolTipText("Click to mark this task as completed.");
	}

}
