/* File: TaskState.java
 *
 * Contains class TaskState
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.task.support;

import edu.cmu.hcii.calo.model.Task;

/**
 * Represents a particular property within the state of a Task. When TaskPaneView generates
 * PropertyChangedEvents with a name of TaskViewPropertyNames#TASK_STATE_PROPERTY_NAME, the old and
 * new values passed in the event will be TaskState objects representing what has changed in what
 * task.
 * 
 * @author Brian Ellis
 * 
 */
public class TaskState {

	/**
	 * Represents a particular property of a task that can change.
	 * 
	 * @author Brian Ellis
	 * 
	 */
	public enum TaskStateProperty {
		COMPLETE,
		STARRED,
		ON_HOLD,
		DUE_DATE,
		DELETED,
		NAME,
		TAGS,
		RESOURCES,
		DATE_COMPLETED
	}

	/**
	 * The task to which this state pertains.
	 */
	private Task task;

	/**
	 * The property that we are concerned with.
	 */
	private TaskStateProperty property;

	/**
	 * The value of that property.
	 */
	private Object value;

	/**
	 * Constructs a TaskState for the given task, noting that \p property has a value of \p value.
	 * 
	 * @param task the task to which this state pertains
	 * @param property the property that we are concerned with
	 * @param value the value of that property
	 */
	public TaskState(Task task, TaskStateProperty property, Object value) {
		this.task = task;
		this.property = property;
		this.value = value;
	}

	/**
	 * Gets the property for this TaskState.
	 * 
	 * @return the property
	 */
	public TaskStateProperty getProperty() {
		return this.property;
	}

	/**
	 * Gets the Task for this TaskState.
	 * 
	 * @return the Task
	 */
	public Task getTask() {
		return this.task;
	}

	/**
	 * The value for this TaskState.
	 * 
	 * @return the Task
	 */
	public Object getValue() {
		return this.value;
	}
}
