/* File: TaskViewPropertyNames.java
 *
 * Contains class TaskViewPropertyNames
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.task.support;

/**
 * The property names that are defined for PropertyChangeEvents emanating from the TaskPaneView.
 * 
 * @author Brian Ellis
 * 
 */
public class TaskViewPropertyNames {

	/**
	 * Fired whenever a TaskView expands or collapses (but does not indicate which one). The old and
	 * new values will be booleans, \c true meaning expanded, \c false meaning not expanded.
	 */
	public static final String EXPANDED_PROPERTY_NAME = "Expanded";

	/**
	 * Fired whenever the state of a TaskView changes, where the parameters of a state are defined
	 * in the TaskState class. The old and new values will be TaskStates, both of which will pertain
	 * to the same Task. Note that firing a TASK_STATE_PROPERTY_NAME property change does NOT imply
	 * that the model has changed; it is the responsibility of the controller to update the model in
	 * response to these events.
	 */
	public static final String TASK_STATE_PROPERTY_NAME = "TaskState";

	/**
	 * Fired whenever the order of a TaskView relative to other TaskViews changes. The old value
	 * will be \c null, and the new value will be a List of three adjacent Task objects in the order
	 * they now appear in the list, with the reordered task in the middle. Either the first or last
	 * Task in the list may be \c null, which indicates that the middle Task should be at the
	 * beginning or end of the list, respectively.
	 */
	public static final String TASK_ORDER_PROPERTY_NAME = "TaskOrder";

	/**
	 * Fired whenever a TaskView starts or stops being dragged (but does not indicate which one).
	 * The old and new values will be booleans, \c true meaning dragging, \c false meaning not
	 * dragging.
	 */
	public static final String DRAGGING_PROPERTY_NAME = "Dragging";

	/**
	 * Fired whenever a TaskView subpane starts or stops showing all its contents.
	 */
	public static final String SUBPANE_SHOWING_ALL_PROPERTY_NAME = "SubpaneShowingAll";

	/**
	 * Fired whenever a TaskView subpane starts or stops being collapsed.
	 */
	public static final String SUBPANE_COLLAPSED_PROPERTY_NAME = "SubpaneCollapsed";
}
