/*
 * File: TrainingMenu.java
 * 
 * Contains class TrainingMenu
 * 
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.training;

import java.awt.event.MouseEvent;

import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;

/**
 * A simple customizable menu containing (non-functional) commands for training CALO.
 * 
 * @author Brian Ellis
 * 
 */
public class TrainingMenu extends JPopupMenu {

	/**
	 * Prevent serialization collisions.
	 */
	private static final long serialVersionUID = -156832116648667567L;

	/**
	 * Constructs a TrainingMenu with the given menu items above the CALO training items.
	 */
	public TrainingMenu(JMenuItem... menuItems) {
		super();
		setup(menuItems);
	}

	/**
	 * Superclass constructor. Do not use.
	 * 
	 * @param arg0 the title of this menu
	 */
	@SuppressWarnings("unused")
	private TrainingMenu(String arg0) {
		super(arg0);
		setup();
	}

	/**
	 * Sets up the visual appearance of this menu.
	 * 
	 * @param menuItems the menu items to prepend to the training items.
	 */
	private void setup(JMenuItem... menuItems) {
		for (JMenuItem menuItem : menuItems) {
			this.add(menuItem);
		}
		this.addSeparator();
		JMenuItem trainingHeaderItem = new JMenuItem("Training CALO:");
		trainingHeaderItem.setEnabled(false);
		this.add(trainingHeaderItem);
		this.add(new JMenuItem("This is incorrect"));
		this.add(new JMenuItem("This is almost correct"));
		this.add(new JMenuItem("More training..."));
	}

	/**
	 * Sets the words this menu should use in the titles of its menu items when referring to
	 * correctness for the purposes of training CALO. The defaults are, unsurprisingly, "correct"
	 * and "incorrect", but in certain circumstances it may be desirable to use different terms:
	 * "relevant" and "irrelevant", "important" and "not important", etc.
	 * 
	 * @param correctWord the word or phrase the menu should use to indicate correctness
	 * @param incorrectWord the word or phrase the menu should use to indicate incorrectness
	 */
	public void setCorrectTerminology(String correctWord, String incorrectWord) {
		this.remove(this.getComponentCount() - 1);
		this.remove(this.getComponentCount() - 1);
		this.remove(this.getComponentCount() - 1);

		this.add(new JMenuItem("This is " + incorrectWord));
		this.add(new JMenuItem("This is almost " + correctWord));
		this.add(new JMenuItem("More training..."));
	}

	/**
	 * Shows this menu in response to a given mouse event, if and only if the mouse event is the
	 * result of a right-click.
	 * 
	 * @param e the mouse event to use to determine whether this was a right-click
	 * @return \c true if the menu was shown, \c false otherwise
	 */
	public boolean showIfRightClick(MouseEvent e) {
		if (!e.isMetaDown()) {
			return false;
		}

		this.setLocation(e.getXOnScreen(), e.getYOnScreen());
		this.setVisible(true);
		return true;
	}
}
