/* File: TrainingMenuListener.java
 *
 * Contains class TrainingMenuListener
 *
 * Author: Brian Ellis
 */

package edu.cmu.hcii.calo.view.training;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JMenuItem;

/**
 * A simple mouse listener that can be attached to a component to show a customized CALO Training
 * menu whenever it is right-clicked.
 * 
 * @author Brian Ellis
 * 
 */
public abstract class TrainingMenuListener extends MouseAdapter {

	/**
	 * The menu itself. Lazily constructed.
	 */
	private TrainingMenu menu = null;

	/**
	 * Should be implemented by instances to return the menu items that will be prepended to the
	 * menu when it is displayed.
	 * 
	 * @return the menu items to prepend
	 */
	public abstract JMenuItem[] getItems();

	/**
	 * Returns the menu that will be shown on right-click, creating it if necessary. getItems() will
	 * be called to populate the menu the first time this method is called.
	 * 
	 * @return the menu
	 */
	public TrainingMenu getMenu() {
		if (this.menu == null) {
			this.menu = new TrainingMenu(this.getItems());
		}
		return this.menu;
	}

	/**
	 * Invoked when the mouse is clicked in the attached control. Shows the menu if the event was
	 * fired as the result of a right-click.
	 * 
	 * @param e the mouse event
	 */
	@SuppressWarnings("synthetic-access")
	@Override
	public void mouseClicked(MouseEvent e) {
		if (this.menu == null) {
			this.menu = new TrainingMenu(this.getItems());
		}
		this.menu.showIfRightClick(e);
	}
}
